# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).


## [0.8.X]

### Added
- Include button to add velocities curves.

### Removed

### Fixed
- Add Manifest to include Markdown and Licence files on the package

## [0.7.1]

### Added
- Application icon
- Add configuration for the signals set folder

### Removed
- Do backups: it was moved from icepap library to IcepapCMS as snapshots
- Status dialog: it will be implemented on the IcepapCMS console
- Esync button: it will be implemented on the IcepapCMS

### Fixed
- Load dynamically the UI files
- Add protection on the export signals settings
- Show axes labels on black background configuration
- Wrong windows opacity configuration does not allow to see the main windows 
  depending on the display configuration.

## [0.6.4]

### Added
- Allow to change the plot background.
- Allow to change color and form of the signal plotted.
- Add Trace Correction.
- Add axis control buttons.
- Import and Export signal set configuration to file.
- Allow to do backups

### Removed
- Button save to file
- Load dynamically the UI files

### Fixed


## [0.5.2] 

### Added
- Migrate to python 3
- Migrate to Qt 5
- Add protection to create configuration folders 
- Add the axis as optional parameter on the script. 

### Fixed
- Fix classifiers to upload to PyPi

## [0.4.0] 

### Added
- Allow to save on the file
- Allow to save the setting to a file

### Fixed


## [0.3.0] 

### Added
- Allow to set the signals from command line.

### Fixed

## [0.2.1] 

### Added
- Update setting dialog: allows to configure the axis X.
- Allows to change the port

### Fixed
- Fix bug in setting and adjusted dialogs.
- Remove the possibility to open two settings dialogs. 
- Do not allow to open more than one setting dialog

## [0.1.0] 

### Added
- First version of the Oscilloscope mode.

### Fixed

#
[keepachangelog.com]: http://keepachangelog.com
[0.1.0]: https://github.com/ALBA-Synchrotron/IcepapOCS/compare/0.1.0...0.2.0
[0.2.1]: https://github.com/ALBA-Synchrotron/IcepapOCS/compare/0.2.0...0.2.1
[0.3.0]: https://github.com/ALBA-Synchrotron/IcepapOCS/compare/0.2.1...0.3.0
[0.4.0]: https://github.com/ALBA-Synchrotron/IcepapOCS/compare/0.3.0...0.4.0
[0.5.2]: https://github.com/ALBA-Synchrotron/IcepapOCS/compare/0.4.0...0.5.2
[0.6.4]: https://github.com/ALBA-Synchrotron/IcepapOCS/compare/0.5.2...0.6.4
[0.7.1]: https://github.com/ALBA-Synchrotron/IcepapOCS/compare/0.6.4...0.7.1
[0.8.x]: https://github.com/ALBA-Synchrotron/IcepapOCS/compare/0.7.1...HEAD


